summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldercachedimap.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfoldercachedimap.h')
-rw-r--r--kmail/kmfoldercachedimap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/kmfoldercachedimap.h b/kmail/kmfoldercachedimap.h
index dfef783ab..bd084f00a 100644
--- a/kmail/kmfoldercachedimap.h
+++ b/kmail/kmfoldercachedimap.h
@@ -285,8 +285,8 @@ public:
void setACLList( const ACLList& arr );
// Reimplemented so the mStatusChangedLocally bool can be set
- virtual void setqStatus( int id, KMMsgtqStatus status, bool toggle );
- virtual void setqStatus( TQValueList<int>& ids, KMMsgtqStatus status, bool toggle );
+ virtual void seStatus( int id, KMMsgStatus status, bool toggle );
+ virtual void seStatus( TQValueList<int>& ids, KMMsgStatus status, bool toggle );
TQString annotationFolderType() const { return mAnnotationFolderType; }
@@ -405,7 +405,7 @@ protected:
virtual void timerEvent( TQTimerEvent* );
/* update progress status */
- void newState( int progress, const TQString& synctqStatus );
+ void newState( int progress, const TQString& syncStatus );
/** See if there is a better parent then this folder */
KMFolderCachedImap* findParent( const TQString& path, const TQString& name );
@@ -590,7 +590,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
* UIDs added by setqStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status
* of the mails in this folder.
@@ -590,7 +590,7 @@ private:
bool mSharedSeenFlagsChanged;
/**
- * UIDs added by setqStatus. Indicates that the client has changed
+ * UIDs added by seStatus. Indicates that the client has changed
* the status of those mails. The mail flags for changed mails will be
* uploaded to the server, overwriting the server's notion of the status